@@ -1,11 +1,10 @@
 /*
 ** Chameleon header file. 
-** ff, 1998.
+** ff, 1999.
 */
 
-#define VERSION "Chameleon 1.0 by ff\n"
+#define VERSION "Chameleon 1.1 by ff"
 #define MAXPATH 128
-#define CONFFILE ".chamrc"
 
 #define USAGE   "Usage: chameleon [hexrgb|color name|filename] [-t]\n\n"\
 		"Examples:\n\tchameleon \"#c6c6ff\"\n\t"\
